/***************************************************************************
 begin                : Sat Mar 9 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : chubinger@irrsinnig.org
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFNEWCHAINDLG_H
#define KMFNEWCHAINDLG_H

#include <tqwidget.h>
#include <tqstringlist.h>
#include "kmyfirewallchaineditornewchain.h"
#include <tqevent.h>
/**
  *@author Christian Hubinger
  */


namespace KMF {
class KMFIPTDoc;
class KMFError;
class KMFErrorHandler;
class KMFCheckInput;

class KMFNewChainDlg : public KMyFirewallChainEditorNewChain {
	TQ_OBJECT
  
public:
	KMFNewChainDlg( TQWidget *parent = 0, const char *name = 0, bool modal = FALSE, WFlags fl = 0 );
	~KMFNewChainDlg();
	void loadDoc( KMFIPTDoc* doc );

public slots:    // Public slots
	/** No descriptions */
	void accept();

private:
	KMFIPTDoc* kmfdoc;
	KMFError* m_err;
	KMFErrorHandler* m_err_handler;
	KMFCheckInput* m_check_input;

protected:
	virtual void keyPressEvent ( TQKeyEvent * e );


signals:
	void sigUpdateView();

};
}
#endif
